2
0

Cleanup/wg init (#260)

* remove wg_init and wg_finalize from functional tests

* Remove wg_init and wg_finalize from examples

* deprecate wg_init/finalize

* Updated docs

* Typo in documentation

---------

Co-authored-by: Yiltan <yiltan@amd.com>

[ROCm/rocshmem commit: 6e7277b544]
Este cometimento está contido em:
Aurelien Bouteiller
2025-10-07 14:34:18 -04:00
cometido por GitHub
ascendente 192c549d40
cometimento 8837414042
32 ficheiros modificados com 23 adições e 68 eliminações
@@ -39,7 +39,6 @@ __global__ void SyncAllTest(int loop, int skip, long long int *start_time,
int wg_id = get_flat_grid_id();
int wf_id = t_id / wf_size;
rocshmem_wg_init();
for (int i = 0; i < loop + skip; i++) {
if (hipThreadIdx_x == 0 && i == skip) {
@@ -84,7 +83,6 @@ __global__ void SyncAllTest(int loop, int skip, long long int *start_time,
end_time[wg_id] = wall_clock64();
}
rocshmem_wg_finalize();
}
/******************************************************************************